<?php

/* declare each item separately - not as an entire array() */
$lang['orient'] = 'Check image files for correct visual orientation. (v1.0)';
$lang['orient_explanation'] = 'This will allow you to examine image files for orientation and dimensions.';

class CPG_ToolOrient extends AdminTool
{
	protected $toolname = 'orient';
	public $progressive = false;

	public function describe ()
	{
		return $this->_('orient');
	}

	public function displayUI ()
	{
		if (!$this->scp->keyExists('act')) return $this->_('orient_explanation');

		require_once 'modimg.php';
		switch ($this->scp->getRaw('act')) {
			case 'swap':
			//	require_once 'modimg.php';
				$this->performAction(false);
				break;
			case 'seto':
				$ocode = $this->scp->getInt('ocode');
				break;
			default:
				$this->performAction();
		}
	}

	public function total ()
	{
		$result = cpg_db_query("SELECT COUNT(pid) FROM {$this->config['TABLE_PICTURES']}{$this->albstr}");
		list($count) = $result->fetchRow(true);
		return $count;
	}

	// just display a user interface that will allow ajax actions
	public function action ()
	{
		echo '<style>'.file_get_contents('tools/orient/orient.css').'</style>';
		echo '<script>var ot_albstr = "'.$this->albstr.'";</script>';
		echo '<script>'.file_get_contents('tools/orient/orient.js').'</script>';
		echo <<< EOT
<div class="ot_main">
	<button class="ot_getbut" onclick="ot_getImg()">Get Next</button>
	Orientation:&nbsp;<select id="ot_orient" onchange="ot_enable(this)">
		<option value="-1">&nbsp;&lt;UNKNOWN&gt;</option>
		<option value="1">1: Normal (0 deg)</option>
		<option value="2">2: Mirrored</option>
		<option value="3">3: Upside-down</option>
		<option value="4">4: Upside-down Mirrored</option>
		<option value="5">5: 90 deg CW Mirrored</option>
		<option value="6">6: 90 deg CCW</option>
		<option value="7">7: 90 deg CCW Mirrored</option>
		<option value="8">8: 90 deg CW</option>
	</select>
	<button id="ot_doit" onclick="ot_dswap()">&lt; Apply</button>
	<button id="ot_updx" onclick="ot_updx()">Update CPG Exif Table</button>
</div>
<div id="ot_info" class="ot_info"></div>
<div id="ot_image" class="ot_image"></div>
EOT;
	}

	private function performAction ($nxt=true)
	{
		$albstr = $this->scp->getRaw('albstr');
		$wand = $albstr ? 'AND pwidth > 0 AND' : 'WHERE pwidth > 0 AND ';
		$startpic = $this->scp->keyExists('index') ? $this->scp->getInt('index') : 0;
		if ($nxt) {
			$result = cpg_db_query("SELECT * FROM {$this->config['TABLE_PICTURES']}{$albstr} {$wand} pid > ".$startpic.' LIMIT 1');
		} else {
			$result = cpg_db_query("SELECT * FROM {$this->config['TABLE_PICTURES']} WHERE pid = ".$startpic);
		}
		$row = $result->fetchAssoc();
		$imgpth = $this->config['fullpath'] . $row['filepath'] . $row['filename'];
		if (!$nxt && $this->scp->keyExists('oval')) {
			$mi = new ModImg($imgpth);
			$mi->setOrient($this->scp->getInt('oval'));
		}
		if (!$nxt && $this->scp->keyExists('updx')) {
			$mi = new ModImg($imgpth);
			$this->updateExif($startpic, $mi->getOrient(true));
		}
		$info = '';
		$igis = getimagesize($imgpth);
		if ($igis) {
			$info = 'PHP Size: '.$igis[1].'x'.$igis[0].'&nbsp;&nbsp;&nbsp;&nbsp;';
		}
		$info .= 'CPG Size: '.$row['pheight'].'x'.$row['pwidth'].'&nbsp;&nbsp;&nbsp;&nbsp;';
		$mi = new ModImg($imgpth);
		//$info .= $mi->getOrient().'&nbsp;&nbsp;&nbsp;&nbsp;';
		//$info .= $mi->hw().'&nbsp;&nbsp;&nbsp;&nbsp;';
		$imgsrc = $imgpth.'?t='.time();
		$iwh = ' width="'.$row['pwidth'].'" height="'.$row['pheight'].'"';
		echo json_encode([
			'idx'=>$row['pid'],
			'img'=>'<img src="'.$imgsrc.'"'.$iwh.' style="height:100%;width:auto" />',
			'ori'=>$mi->getOrient(),
			'info'=>$info
			]);

		return $row['pid'];
		return false;
	}

	private function updateExif ($pid, $o)
	{
		$result = cpg_db_query("SELECT exifData FROM {$this->config['TABLE_EXIF']} WHERE pid = $pid");
		if ($result->numRows() > 0) {
			$row = $result->fetchAssoc(true);
			$exif = unserialize($row['exifData']);
			$exif['Orientation'] = $o;
			cpg_db_query("UPDATE {$this->config['TABLE_EXIF']} SET exifData = '".addslashes(serialize($exif))."' WHERE pid = $pid");
		}
	}

}
